searchData={"items":[{"type":"module","title":"WaifuVault","doc":"This API wrapper is meant to conform to the [WaifuVault Swagger docs](https://waifuvault.moe/api-docs/).\n\n  To include in your project:\n  ```\n  # In your mix.exs deps/0 function\n  {:waifu_vault, \"~> 1.0.0\"}\n  ```\n\n  To Use:\n  ```\n  # In your_file.ex\n  require WaifuVault\n  ```","ref":"WaifuVault.html"},{"type":"function","title":"WaifuVault.associate_file/2","doc":"The associate_file/2 function connects one or more files to an album.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementAssociateFileWithAlbum)\n\n  ```\n  iex> {:ok, album_response} = WaifuVault.associate_file(\"some-valid-album-token\", [\"valid-file1\". \"valid-file2\"])\n  {:ok, Map}\n  ```","ref":"WaifuVault.html#associate_file/2"},{"type":"function","title":"WaifuVault.create_album/2","doc":"The create_album/2 function creates an album within the specified bucket.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementCreateAlbum)\n\n  ```\n  iex> {:ok, album} = WaifuVault.create_album(\"some-bucket-token\", \"album-name\")\n  {:ok, Map}\n  ```","ref":"WaifuVault.html#create_album/2"},{"type":"function","title":"WaifuVault.create_bucket/0","doc":"Buckets are virtual collections that are linked to your IP and a token. When you create a bucket,\n  you will receive a bucket token that you can use in get_bucket/1 to get all the files in that bucket.\n  Later calls to create_bucket/0 will return the same token as long as your IP address doesn't change.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Bucket%20Management/bucketManagementCreateBucket)\n\n  ```\n  iex> {:ok, bucket} = WaifuVault.create_bucket()\n  {:ok, \"some-uuid-type-value\"}\n  ```","ref":"WaifuVault.html#create_bucket/0"},{"type":"function","title":"WaifuVault.delete_album/2","doc":"The delete_album/2 function removes the specified album.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementDeleteAlbum)\n\n  ```\n  # First deletion attempt\n  iex> WaifuVault.delete_album(\"album-token\")\n  {:ok, %{\"description\" => \"album deleted\", \"success\" => true}}\n\n  # Attempt a second deletion\n  iex> WaifuVault.delete_album(\"album-token\")\n  {:error,\n  \"Error 400 (BAD_REQUEST): Album with token album-token not found\"}\n  ```","ref":"WaifuVault.html#delete_album/2"},{"type":"function","title":"WaifuVault.delete_bucket/1","doc":"Deleting a bucket will delete the bucket and all the files it contains.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Bucket%20Management/bucketManagementDeleteBucket)\n\n  IMPORTANT: All contained files will be DELETED along with the Bucket!\n\n  ```\n  iex> {:ok, boolean} = WaifuVault.delete_bucket(\"some-valid-uuid-token\")\n  {:ok, true}\n  ```","ref":"WaifuVault.html#delete_bucket/1"},{"type":"function","title":"WaifuVault.delete_file/1","doc":"The delete_file/1 function returns `{:ok, true}` for a successful deletion.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadDeleteEntry)\n\n  ```\n  iex> {:ok, true} = WaifuVault.delete_file(file_token)\n  {:ok, true}\n  ```","ref":"WaifuVault.html#delete_file/1"},{"type":"function","title":"WaifuVault.disassociate_file/2","doc":"The disassociate_file/2 function dis-connects one or more files from an album.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementDisassociateFileWithAlbum)\n\n  ```\n  iex> {:ok, album_response} = WaifuVault.disassociate_file(\"some-valid-album-token\", [\"valid-file1\". \"valid-file2\"])\n  {:ok, Map}\n  ```","ref":"WaifuVault.html#disassociate_file/2"},{"type":"function","title":"WaifuVault.download_album/2","doc":"The download_album/2 function fetches a zip file containing either the whole album, or specified files.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementDownloadFiles)\n\n  ```\n  iex> {:ok, zip_data} = WaifuVault.download_album(\"some-valid-album-token\", [\"file.jpg\", \"file2.jpg\"])\n  {:ok, zip_data}\n  ```","ref":"WaifuVault.html#download_album/2"},{"type":"function","title":"WaifuVault.file_info/2","doc":"The file_info/2 function retrieves file metadata for the specified file token.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadGetInfo)\n\n  ```\n  iex> {:ok, map} = WaifuVault.file_info(\"some-valid-file-token\")\n  {:ok, %{...}}\n  ```","ref":"WaifuVault.html#file_info/2"},{"type":"function","title":"WaifuVault.get_album/1","doc":"The get_album/1 function returns album info, given the private token.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementGetAlbum)\n\n  ```\n  iex> {:ok, album_response} = WaifuVault.get_album(\"some-valid-album-token\")\n  {:ok, Map}\n  ```","ref":"WaifuVault.html#get_album/1"},{"type":"function","title":"WaifuVault.get_bucket/1","doc":"The get_bucket/1 function returns the list of files and albums contained in a bucket.\n  The bucket has a `dateCreated` value that can be converted\n  with `DateTime.from_unix( dateCreated, :millisecond)`\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Bucket%20Management/bucketManagementGetBucket)\n\n  Individual files have a `retentionPeriod` which is the UNIX timestamp in milliseconds for when the\n  file will expire. It can be converted with `DateTime.from_unix( retentionPeriod, :millisecond)`\n\n  ```\n  iex> {:ok, boolean} = WaifuVault.get_bucket(\"some-valid-uuid-token\")\n  {:ok, Map}\n  ```","ref":"WaifuVault.html#get_bucket/1"},{"type":"function","title":"WaifuVault.get_file/2","doc":"The get_file/2 function retrieves the contents of the specified file, which can be specified via URL or by token\n  (which is used to *look up* the URL).\n  The password, if passed, is ignored unless the file is password-protected.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadGetInfo)\n\n  ```\n  iex> {:ok, bitstring} = WaifuVault.get_file(\"some-valid-album-token\", \"some-password\")\n  {:ok, < >}\n  ```","ref":"WaifuVault.html#get_file/2"},{"type":"function","title":"WaifuVault.get_file_stats/0","doc":"The get_file_stats/0 function returns server limits for the current IP address.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Resource%20Management/resourceManagementStorage)\n\n  ```\n  iex> WaifuVault.get_file_stats\n  {:ok, %{\"recordCount\" => 1420, \"recordSize\" => \"1.92 GiB\"}}\n  ```","ref":"WaifuVault.html#get_file_stats/0"},{"type":"function","title":"WaifuVault.get_restrictions/0","doc":"The get_restrictions/0 function returns restrictions for the current IP address.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Resource%20Management/resourceManagementGetRestrictions)\n\n  ```\n  iex> {:ok, restrictions} = WaifuVault.get_restrictions()\n  {:ok,\n    [\n      %{type: \"MAX_FILE_SIZE\", value: 104857600},\n      %{\n        type: \"BANNED_MIME_TYPE\",\n        value: \"application/x-dosexec,application/x-executable,application/x-hdf5,application/x-java-archive,application/vnd.rar\"\n      }\n    ]\n  }\n  ```","ref":"WaifuVault.html#get_restrictions/0"},{"type":"function","title":"WaifuVault.revoke_album/1","doc":"The revoke_album/1 function disables public sharing.\n  Note that future calls to share_album/1 will give it a new public token and new public URL.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementRevokeShare)\n\n  ```\n  iex> {:ok, album_response} = WaifuVault.revoke_album(\"some-valid-album-token\")\n  {:ok, \"album unshared\"}\n  ```","ref":"WaifuVault.html#revoke_album/1"},{"type":"function","title":"WaifuVault.share_album/1","doc":"The share_album/1 function takes the album's private token and returns the public URL.\n  Calling share_album/1 on an already-shared album will just return its token.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/Album%20management/albumManagementShareAlbum)\n\n  ```\n  iex> {:ok, url} = WaifuVault.share_album(\"some-valid-album-token\")\n  {:ok, \"https://waifuvault.moe/public-token\"}\n  iex> {:ok, token} = WaifuVault.share_album(\"some-valid-album-token\")\n  {:ok, \"public-token\"}\n  ```","ref":"WaifuVault.html#share_album/1"},{"type":"function","title":"WaifuVault.update_file/2","doc":"The update_file/2 function returns `{:ok, file_data}` for a successful update.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadModifyEntry)\n\n  ```\n  iex> {:ok, true} = WaifuVault.update_file(file_token, %{...})\n  {:ok, true}\n  ```","ref":"WaifuVault.html#update_file/2"},{"type":"function","title":"WaifuVault.upload_file_from_buffer/3","doc":"The upload_file_from_buffer/3 function posts the data to the server, returning a fileResponse map.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadAddEntry)\n  [and parallel Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadAddEntry_1)\n\n  ```\n  iex> {:ok, buffer} = File.read(\"some/local/file\")\n  iex> {:ok, fileResponse} = WaifuVault.upload_file_from_buffer(buffer, \"file.name\", %{expires: \"10m\"})\n  {:ok, %{...}}\n  ```","ref":"WaifuVault.html#upload_file_from_buffer/3"},{"type":"function","title":"WaifuVault.upload_local_file/3","doc":"The upload_local_file/3 function simplifies the process of uploading a local file with a simple\n  wrapper around upload_file_from_buffer/3. It posts the data to the server, returning a fileResponse map.\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadAddEntry)\n  [and parallel Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadAddEntry_1)\n\n  ```\n  iex> options = %{}\n  iex> {:ok, fileResponse} = WaifuVault.upload_local_file(\"./mix.exs\", \"my_mix.exs\", options)\n  {:ok, %{...}}\n  ```","ref":"WaifuVault.html#upload_local_file/3"},{"type":"function","title":"WaifuVault.upload_via_url/2","doc":"Uploading a file specified via URL. Setting the :bucket option will place the file\n  in the specified bucket (assuming it exists).\n  [Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadAddEntry)\n  [and parallel Swagger docs](https://waifuvault.moe/api-docs/#/File%20Upload/fileUploadAddEntry_1)\n\n  ```\n  iex> options = %{}\n  iex> {:ok, fileResponse} = WaifuVault.upload_via_url(image_url, options)\n  {:ok, %{...}}\n  ```","ref":"WaifuVault.html#upload_via_url/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}